@@ -102,8 +102,9 @@ def _check_for_unknown_fields(cls, data):
         Errors of the fields that were not present in ``cls``.
     """
     errors = {}
-    rogues_found = set(data) - set(cls._fields)
-    if len(rogues_found) > 0:
+    fields = set(getattr(cls, '_initial', {})) | set(data)
+    rogues_found = fields - set(cls._fields)
+    if rogues_found:
         for field_name in rogues_found:
             errors[field_name] = [u'%s is an illegal field.' % field_name]
     return errors
